//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[UnionShantenResult](index.md)/[chitoi](chitoi.md)

# chitoi

[common]\

@EncodeDefault

val [chitoi](chitoi.md): [ChitoiShantenResult](../-chitoi-shanten-result/index.md)? = null

标准形向听分析结果
